@@ -94,7 +94,15 @@
 #'   the x-values of the supporting points will be \code{c(0, 0.5, 1)} and
 #'   \code{c(0, 0.25, 0.5, 0.75, 1)} when \code{x_bins = 2}
 #'   and \code{x_bins = 4}, respectively. All corresponding y-values of
-#'   the supporting points are calculated.
+#'   the supporting points are calculated. \code{x_bins} is effective only
+#'   when \code{mode} is set to \code{rocprc} or \code{prcroc}.
+#'
+#' @param interpolate A Boolean value to specify whether or not
+#'   interpolation of ROC and precision-recall curves are
+#'   performed. \code{x_bins} and \code{calc_avg} are
+#'   ignored and  when \code{x_bins} is set to \code{FALSE}.
+#'   \code{interpolate} is effective only when \code{mode} is set
+#'   to \code{rocprc} or \code{prcroc}.
 #'
 #' @param ... These additional arguments are passed to \code{\link{mmdata}}
 #'   for data preparation.
@@ -144,7 +152,8 @@
 #'   }
 #'
 #'   \item The \code{evalmod} function returns the \code{aucroc} S3 object
-#'   when \code{mode} is "aucroc", which can be used with 'print' and 'as.data.frame'.
+#'   when \code{mode} is "aucroc", which can be used with 'print'
+#'   and 'as.data.frame'.
 #'
 #' }
 #'
@@ -172,8 +181,10 @@
 #' sscurves
 #'
 #' ## Generate an sspoints object that contains basic evaluation measures
-#' sspoints <- evalmod(mode = "basic", scores = P10N10$scores,
-#'                     labels = P10N10$labels)
+#' sspoints <- evalmod(
+#'   mode = "basic", scores = P10N10$scores,
+#'   labels = P10N10$labels
+#' )
 #' sspoints
 #'
 #'
@@ -184,7 +195,8 @@
 #' ## Create sample datasets with 100 positives and 100 negatives
 #' samps <- create_sim_samples(1, 100, 100, "all")
 #' mdat <- mmdata(samps[["scores"]], samps[["labels"]],
-#'                modnames = samps[["modnames"]])
+#'   modnames = samps[["modnames"]]
+#' )
 #'
 #' ## Generate an mscurve object that contains ROC and Precision-Recall curves
 #' mscurves <- evalmod(mdat)
@@ -202,8 +214,9 @@
 #' ## Create sample datasets with 100 positives and 100 negatives
 #' samps <- create_sim_samples(4, 100, 100, "good_er")
 #' mdat <- mmdata(samps[["scores"]], samps[["labels"]],
-#'                modnames = samps[["modnames"]],
-#'                dsids = samps[["dsids"]])
+#'   modnames = samps[["modnames"]],
+#'   dsids = samps[["dsids"]]
+#' )
 #'
 #' ## Generate an smcurve object that contains ROC and Precision-Recall curves
 #' smcurves <- evalmod(mdat)
@@ -221,8 +234,9 @@
 #' ## Create sample datasets with 100 positives and 100 negatives
 #' samps <- create_sim_samples(4, 100, 100, "all")
 #' mdat <- mmdata(samps[["scores"]], samps[["labels"]],
-#'                modnames = samps[["modnames"]],
-#'                dsids = samps[["dsids"]])
+#'   modnames = samps[["modnames"]],
+#'   dsids = samps[["dsids"]]
+#' )
 #'
 #' ## Generate an mmcurve object that contains ROC and Precision-Recall curves
 #' mmcurves <- evalmod(mdat)
@@ -241,9 +255,11 @@
 #' data(M2N50F5)
 #'
 #' ## Speficy nessesary columns to create mdat
-#' cvdat <- mmdata(nfold_df = M2N50F5, score_cols = c(1, 2),
-#'                 lab_col = 3, fold_col = 4,
-#'                 modnames = c("m1", "m2"), dsids = 1:5)
+#' cvdat <- mmdata(
+#'   nfold_df = M2N50F5, score_cols = c(1, 2),
+#'   lab_col = 3, fold_col = 4,
+#'   modnames = c("m1", "m2"), dsids = 1:5
+#' )
 #'
 #' ## Generate an mmcurve object that contains ROC and Precision-Recall curves
 #' cvcurves <- evalmod(cvdat)
@@ -254,9 +270,11 @@
 #' cvpoints
 #'
 #' ## Specify mmdata arguments from evalmod
-#' cvcurves2 <- evalmod(nfold_df = M2N50F5, score_cols = c(1, 2),
-#'                      lab_col = 3, fold_col = 4,
-#'                      modnames = c("m1", "m2"), dsids = 1:5)
+#' cvcurves2 <- evalmod(
+#'   nfold_df = M2N50F5, score_cols = c(1, 2),
+#'   lab_col = 3, fold_col = 4,
+#'   modnames = c("m1", "m2"), dsids = 1:5
+#' )
 #' cvcurves2
 #'
 #'
@@ -268,8 +286,10 @@
 #' data(P10N10)
 #'
 #' # 'aucroc' S3 object
-#' uauc1 <- evalmod(scores = P10N10$scores, labels = P10N10$labels,
-#'                  mode="aucroc")
+#' uauc1 <- evalmod(
+#'   scores = P10N10$scores, labels = P10N10$labels,
+#'   mode = "aucroc"
+#' )
 #'
 #' # print 'aucroc'
 #' uauc1
@@ -283,13 +303,16 @@
 #'
 #' # a function to test mode = "rocprc"
 #' func_evalmod_rocprc <- function(samp) {
-#'    curves <- evalmod(scores = samp$scores, labels = samp$labels)
-#'    aucs <- auc(curves)
+#'   curves <- evalmod(scores = samp$scores, labels = samp$labels)
+#'   aucs <- auc(curves)
 #' }
 #'
 #' # a function to test mode = "aucroc"
 #' func_evalmod_aucroc <- function(samp) {
-#'   uaucs <- evalmod(scores = samp$scores, labels = samp$labels, mode="aucroc")
+#'   uaucs <- evalmod(
+#'     scores = samp$scores, labels = samp$labels,
+#'     mode = "aucroc"
+#'   )
 #'   as.data.frame(uaucs)
 #' }
 #'
@@ -306,8 +329,7 @@ evalmod <- function(mdat, mode = NULL, scores = NULL, labels = NULL,
                     modnames = NULL, dsids = NULL,
                     posclass = NULL, na_worst = TRUE, ties_method = "equiv",
                     calc_avg = TRUE, cb_alpha = 0.05, raw_curves = FALSE,
-                    x_bins = 1000, ...) {
-
+                    x_bins = 1000, interpolate = TRUE, ...) {
   # Validation
   new_mode <- .get_new_mode(mode, mdat, "rocprc")
   new_ties_method <- .pmatch_tiesmethod(ties_method, ...)
@@ -315,24 +337,29 @@ evalmod <- function(mdat, mode = NULL, scores = NULL, labels = NULL,
   if (x_bins == 0) {
     x_bins <- 1
   }
-  .validate_evalmod_args(new_mode, modnames, dsids, posclass, new_na_worst,
-                         new_ties_method, calc_avg, cb_alpha, raw_curves,
-                         x_bins)
+  .validate_evalmod_args(
+    new_mode, modnames, dsids, posclass, new_na_worst,
+    new_ties_method, calc_avg, cb_alpha, raw_curves,
+    x_bins, interpolate
+  )
 
   # Create mdat if not provided
   if (missing(mdat)) {
     mdat <- mmdata(scores, labels,
-                   modnames = modnames, dsids = dsids, posclass = posclass,
-                   na_worst = new_na_worst, ties_method = new_ties_method,
-                   mode = new_mode, ...)
+      modnames = modnames, dsids = dsids, posclass = posclass,
+      na_worst = new_na_worst, ties_method = new_ties_method,
+      mode = new_mode, ...
+    )
   }
   .validate(mdat)
 
   # Call pipeline controller
-  pl_main(mdat, mode = new_mode, calc_avg = calc_avg, cb_alpha = cb_alpha,
-          raw_curves = raw_curves, x_bins = x_bins, na_worst = new_na_worst,
-          ties_method = new_ties_method, validate = FALSE)
-
+  pl_main(mdat,
+    mode = new_mode, calc_avg = calc_avg, cb_alpha = cb_alpha,
+    raw_curves = raw_curves, x_bins = x_bins, interpolate = interpolate,
+    na_worst = new_na_worst, ties_method = new_ties_method,
+    validate = FALSE
+  )
 }
 
 #
@@ -348,10 +375,14 @@ evalmod <- function(mdat, mode = NULL, scores = NULL, labels = NULL,
   new_mode <- NA
   if (!is.null(mode)) {
     new_mode <- .pmatch_mode(mode)
-    if (new_mode != "aucroc" && !is.na(mdat_mode) &&  mdat_mode == "aucroc") {
-      stop(paste0("Invalid 'mode': evalmod <- '", new_mode,
-                  "'', mmdata <- '", mdat_mode, "'"),
-           call. = FALSE)
+    if (new_mode != "aucroc" && !is.na(mdat_mode) && mdat_mode == "aucroc") {
+      stop(
+        paste0(
+          "Invalid 'mode': evalmod <- '", new_mode,
+          "'', mmdata <- '", mdat_mode, "'"
+        ),
+        call. = FALSE
+      )
     }
   } else if (!is.na(mdat_mode)) {
     new_mode <- mdat_mode
@@ -370,8 +401,7 @@ evalmod <- function(mdat, mode = NULL, scores = NULL, labels = NULL,
 .validate_evalmod_args <- function(mode, modnames, dsids,
                                    posclass, na_worst, ties_method,
                                    calc_avg, cb_alpha, raw_curves,
-                                   x_bins) {
-
+                                   x_bins, interpolate) {
   # Check mode
   .validate_mode(mode)
 
@@ -404,4 +434,6 @@ evalmod <- function(mdat, mode = NULL, scores = NULL, labels = NULL,
   # Check x_bins
   .validate_x_bins(x_bins)
 
+  # Check interpolate
+  .validate_interpolate(interpolate)
 }
