@@ -4,7 +4,6 @@
 .pl_main_basic <- function(mdat, model_type, dataset_type, class_name_pf,
                            calc_avg = TRUE, cb_alpha = 0.05,
                            raw_curves = FALSE) {
-
   if (dataset_type == "single") {
     calc_avg <- FALSE
     raw_curves <- TRUE
@@ -19,26 +18,35 @@
       } else {
         cl <- "negative"
       }
-      err_msg <- paste0("Basic measures cannot be calculated. ",
-                        "Only a single class (", cl, ") ",
-                        "found in dataset (modname: ", attr(mdat[[s]], "modname"),
-                        ", dsid: ",attr(mdat[[s]], "dsid"), ").")
+      err_msg <- paste0(
+        "Basic measures cannot be calculated. ",
+        "Only a single class (", cl, ") ",
+        "found in dataset (modname: ",
+        attr(mdat[[s]], "modname"),
+        ", dsid: ", attr(mdat[[s]], "dsid"), ")."
+      )
       stop(err_msg, call. = FALSE)
     }
     cdat <- create_confmats(mdat[[s]], keep_fmdat = TRUE)
-    pevals <- calc_measures(cdat)
+    calc_measures(cdat)
   }
   lpoints <- lapply(seq_along(mdat), plfunc)
 
   # Summarize points by evaluation measure
   grpfunc <- function(m) {
-    .summarize_points(lpoints, m, "pointgrp", mdat, dataset_type,
-                      calc_avg, cb_alpha)
+    .summarize_points(
+      lpoints, m, "pointgrp", mdat, dataset_type,
+      calc_avg, cb_alpha
+    )
   }
-  eval_names <- c("score", "label", "error", "accuracy", "specificity",
-                  "sensitivity", "precision", "mcc", "fscore")
-  grp_row_names <- c("score", "label", "err", "acc", "sp", "sn", "prec", "mcc",
-                     "fscore")
+  eval_names <- c(
+    "score", "label", "error", "accuracy", "specificity",
+    "sensitivity", "precision", "mcc", "fscore"
+  )
+  grp_row_names <- c(
+    "score", "label", "err", "acc", "sp", "sn", "prec", "mcc",
+    "fscore"
+  )
   grp_points <- lapply(eval_names, grpfunc)
   names(grp_points) <- grp_row_names
 
@@ -60,8 +68,10 @@
     grp_points <- lapply(eval_names, grpfunc3)
     names(grp_points) <- grp_row_names
   }
-  s3obj <- structure(grp_points, class = c(paste0(class_name_pf, "points"),
-                                           "beval_info"))
+  s3obj <- structure(grp_points, class = c(
+    paste0(class_name_pf, "points"),
+    "beval_info"
+  ))
 
   # Set attributes
   attr(s3obj, "eval_summary") <- eval_summary
@@ -71,10 +81,12 @@
   attr(s3obj, "uniq_dsids") <- attr(mdat, "uniq_dsids")
   attr(s3obj, "model_type") <- model_type
   attr(s3obj, "dataset_type") <- dataset_type
-  attr(s3obj, "args") <- list(mode = "basic",
-                              calc_avg = calc_avg,
-                              cb_alpha = cb_alpha,
-                              raw_curves = raw_curves)
+  attr(s3obj, "args") <- list(
+    mode = "basic",
+    calc_avg = calc_avg,
+    cb_alpha = cb_alpha,
+    raw_curves = raw_curves
+  )
   attr(s3obj, "validated") <- FALSE
 
   # Call .validate.class_name()
@@ -86,12 +98,13 @@
 #
 .summarize_points <- function(lpoints, eval_type, class_name, mdat,
                               dataset_type, calc_avg, cb_alpha) {
-
   if (!is.null(lpoints)) {
     # Summarize basic evaluation measures
     grp_func <- function(s) {
-      list(x = lpoints[[s]][["basic"]][["rank"]],
-           y = lpoints[[s]][["basic"]][[eval_type]])
+      list(
+        x = lpoints[[s]][["basic"]][["rank"]],
+        y = lpoints[[s]][["basic"]][[eval_type]]
+      )
     }
     pevals <- lapply(seq_along(lpoints), grp_func)
 
@@ -130,24 +143,27 @@
 # Summarize basic evaluation measures
 #
 .summarize_basic <- function(lpoints, mdat) {
-
   # Summarize AUC of ROC or PRC curves
   modnames <- attr(mdat, "data_info")[["modnames"]]
   dsids <- attr(mdat, "data_info")[["dsids"]]
-  evaltypes <- c("rank", "score", "label", "error", "accuracy",
-                 "specificity","sensitivity", "precision", "mcc", "fscore")
+  evaltypes <- c(
+    "rank", "score", "label", "error", "accuracy",
+    "specificity", "sensitivity", "precision", "mcc", "fscore"
+  )
   elen <- length(evaltypes)
 
-  sbasic <- data.frame(modnames = rep(modnames, each = elen),
-                       dsids = rep(dsids, each = elen),
-                       evaltypes = rep(evaltypes, length(modnames)),
-                       minvals = rep(NA, length(modnames) * elen),
-                       q25vals = rep(NA, length(modnames) * elen),
-                       medianvals = rep(NA, length(modnames) * elen),
-                       meanvals = rep(NA, length(modnames) * elen),
-                       q75vals = rep(NA, length(modnames) * elen),
-                       maxvals = rep(NA, length(modnames) * elen),
-                       stringsAsFactors = FALSE)
+  sbasic <- data.frame(
+    modnames = rep(modnames, each = elen),
+    dsids = rep(dsids, each = elen),
+    evaltypes = rep(evaltypes, length(modnames)),
+    minvals = rep(NA, length(modnames) * elen),
+    q25vals = rep(NA, length(modnames) * elen),
+    medianvals = rep(NA, length(modnames) * elen),
+    meanvals = rep(NA, length(modnames) * elen),
+    q75vals = rep(NA, length(modnames) * elen),
+    maxvals = rep(NA, length(modnames) * elen),
+    stringsAsFactors = FALSE
+  )
 
   for (i in seq_along(lpoints)) {
     for (j in seq_along(evaltypes)) {
@@ -169,14 +185,20 @@
   }
 
   # Validate class items and attributes
-  item_names <- c("score", "label", "err", "acc", "sp", "sn", "prec", "mcc",
-                  "fscore")
-  attr_names <- c("eval_summary", "grp_avg", "data_info", "uniq_modnames",
-                  "uniq_dsids", "model_type", "dataset_type", "args",
-                  "validated")
+  item_names <- c(
+    "score", "label", "err", "acc", "sp", "sn", "prec", "mcc",
+    "fscore"
+  )
+  attr_names <- c(
+    "eval_summary", "grp_avg", "data_info", "uniq_modnames",
+    "uniq_dsids", "model_type", "dataset_type", "args",
+    "validated"
+  )
   arg_names <- c("mode", "calc_avg", "cb_alpha", "raw_curves")
-  .validate_basic(points, class_name, ".pl_main_basic", item_names, attr_names,
-                  arg_names)
+  .validate_basic(
+    points, class_name, ".pl_main_basic", item_names, attr_names,
+    arg_names
+  )
 
   attr(points, "validated") <- TRUE
   points
@@ -221,11 +243,15 @@
 
   # Validate class items and attributes
   item_names <- NULL
-  attr_names <- c("data_info", "eval_type", "uniq_modnames", "uniq_dsids",
-                  "avgcurves", "validated")
+  attr_names <- c(
+    "data_info", "eval_type", "uniq_modnames", "uniq_dsids",
+    "avgcurves", "validated"
+  )
   arg_names <- NULL
-  .validate_basic(pointgrp, "pointgrp", ".summarize_points", item_names,
-                  attr_names, arg_names)
+  .validate_basic(
+    pointgrp, "pointgrp", ".summarize_points", item_names,
+    attr_names, arg_names
+  )
 
   attr(pointgrp, "validated") <- TRUE
   pointgrp
