@@ -22,13 +22,12 @@ test_that("model names and dataset IDs are unchanged", {
 
   expect_equal(mnames[["mn"]], modnames)
   expect_equal(mnames[["ds"]], dsids)
-
 })
 
 test_that("a single dataset ID is assigned", {
   dlen <- 3
   modnames <- c("1", "2", "3")
-  dsids <-  rep(1, 3)
+  dsids <- rep(1, 3)
 
   mnames <- .create_modnames(dlen, modnames, NULL)
 
@@ -39,7 +38,7 @@ test_that("a single dataset ID is assigned", {
 test_that("a single model name is assigned", {
   dlen <- 3
   modnames <- rep("m1", 3)
-  dsids <-  c(1, 2, 3)
+  dsids <- c(1, 2, 3)
 
   mnames <- .create_modnames(dlen, NULL, dsids)
 
@@ -50,10 +49,11 @@ test_that("a single model name is assigned", {
 test_that("model names and dataset IDs are expanded 1", {
   dlen <- 6
   modnames <- c("m1", "m2")
-  dsids <-  c(1, 2, 3)
+  dsids <- c(1, 2, 3)
 
   mnames <- .create_modnames(dlen, modnames, dsids,
-                             expd_first = "dsids")
+    expd_first = "dsids"
+  )
 
   expect_equal(mnames[["mn"]], c(rep("m1", 3), rep("m2", 3)))
   expect_equal(mnames[["ds"]], rep(c(1, 2, 3), 2))
@@ -62,10 +62,11 @@ test_that("model names and dataset IDs are expanded 1", {
 test_that("model names and dataset IDs are expanded 2", {
   dlen <- 6
   modnames <- c("m1", "m2")
-  dsids <-  c(1, 2, 3)
+  dsids <- c(1, 2, 3)
 
   mnames <- .create_modnames(dlen, modnames, dsids,
-                             expd_first = "modnames")
+    expd_first = "modnames"
+  )
 
   expect_equal(mnames[["mn"]], rep(c("m1", "m2"), 3))
   expect_equal(mnames[["ds"]], c(1, 1, 2, 2, 3, 3))
@@ -74,10 +75,11 @@ test_that("model names and dataset IDs are expanded 2", {
 test_that("model names are expanded with a single dataset ID", {
   dlen <- 3
   modnames <- c("m1", "m2", "m3")
-  dsids <-  rep(1, 3)
+  dsids <- rep(1, 3)
 
   mnames <- .create_modnames(dlen, NULL, NULL,
-                             expd_first = "modnames")
+    expd_first = "modnames"
+  )
 
   expect_equal(mnames[["mn"]], modnames)
   expect_equal(mnames[["ds"]], dsids)
@@ -86,10 +88,11 @@ test_that("model names are expanded with a single dataset ID", {
 test_that("dataset IDs are expanded with a single model name", {
   dlen <- 3
   modnames <- rep("m1", 3)
-  dsids <-  seq(3)
+  dsids <- seq(3)
 
   mnames <- .create_modnames(dlen, NULL, NULL,
-                             expd_first = "dsids")
+    expd_first = "dsids"
+  )
 
   expect_equal(mnames[["mn"]], modnames)
   expect_equal(mnames[["ds"]], dsids)
