@@ -19,7 +19,7 @@ test_that("create_confmats() reterns a 'cmats' object", {
 test_that("'fmdat' must be a 'fmdat' object", {
   expect_err_msg <- function(fmdat) {
     err_msg <- "Unrecognized class for .validate()"
-    eval(bquote(expect_error(create_confmats(fmdat), err_msg)))
+    expect_error(create_confmats(fmdat), err_msg)
   }
 
   expect_err_msg(list())
@@ -29,23 +29,31 @@ test_that("'fmdat' must be a 'fmdat' object", {
 test_that("create_confmats() can directly take scores and labels", {
   fmdat <- reformat_data(c(0.1, 0.2, 0.2, 0), c(1, 0, 1, 1))
   cmats1 <- create_confmats(fmdat)
-  cmats2 <- create_confmats(scores = c(0.1, 0.2, 0.2, 0),
-                            labels = c(1, 0, 1, 1))
+  cmats2 <- create_confmats(
+    scores = c(0.1, 0.2, 0.2, 0),
+    labels = c(1, 0, 1, 1)
+  )
 
   expect_equal(cmats1, cmats2)
 })
 
 test_that("create_confmats() accepts arguments for reformat_data()", {
   err_msg <- "Invalid arguments: na.rm"
-  expect_error(create_confmats(scores = c(0.1, 0.2, 0.2, 0),
-                               labels = c(1, 0, 1, 1), na.rm = TRUE),
-               err_msg)
+  expect_error(
+    create_confmats(
+      scores = c(0.1, 0.2, 0.2, 0),
+      labels = c(1, 0, 1, 1), na.rm = TRUE
+    ),
+    err_msg
+  )
 
-  cmats <- create_confmats(scores = c(0.1, 0.2, 0),
-                           labels = c(1, 0, 1),
-                           na_worst = TRUE,
-                           ties_method = "first",
-                           keep_fmdat = TRUE)
+  cmats <- create_confmats(
+    scores = c(0.1, 0.2, 0),
+    labels = c(1, 0, 1),
+    na_worst = TRUE,
+    ties_method = "first",
+    keep_fmdat = TRUE
+  )
 
   expect_equal(.get_obj_arg(cmats, "fmdat", "na_worst"), TRUE)
   expect_equal(.get_obj_arg(cmats, "fmdat", "ties_method"), "first")
@@ -53,19 +61,21 @@ test_that("create_confmats() accepts arguments for reformat_data()", {
 
 test_that("create_confmats() accepts na_worst argument", {
   expect_equal_ranks <- function(scores, na_worst, ranks) {
-    cmats <- create_confmats(scores = scores,
-                             labels = c(1, 0, 1),
-                             na_worst = na_worst,
-                             keep_fmdat = TRUE)
+    cmats <- create_confmats(
+      scores = scores,
+      labels = c(1, 0, 1),
+      na_worst = na_worst,
+      keep_fmdat = TRUE
+    )
 
     fmdat <- .get_obj(cmats, "fmdat")
 
-    eval(bquote(expect_equal(.get_obj_arg(cmats, NULL, "na_worst"), na_worst)))
-    eval(bquote(expect_equal(.get_obj_arg(fmdat, NULL, "na_worst"), na_worst)))
-    eval(bquote(expect_equal(fmdat[["ranks"]], ranks)))
+    expect_equal(.get_obj_arg(cmats, NULL, "na_worst"), na_worst)
+    expect_equal(.get_obj_arg(fmdat, NULL, "na_worst"), na_worst)
+    expect_equal(fmdat[["ranks"]], ranks)
 
     sranks <- .rank_scores(scores, na_worst = na_worst)
-    eval(bquote(expect_equal(sranks[["ranks"]], ranks)))
+    expect_equal(sranks[["ranks"]], ranks)
   }
 
   na1_scores <- c(NA, 0.2, 0.1)
@@ -83,25 +93,23 @@ test_that("create_confmats() accepts na_worst argument", {
 })
 
 test_that("create_confmats() accepts ties_method argument", {
-
   expect_equal_ranks <- function(ties_method, ranks) {
-    cmats <- create_confmats(scores = c(0.1, 0.2, 0.2, 0.2, 0.3),
-                             labels = c(1, 0, 1, 1, 1),
-                             ties_method = ties_method,
-                             keep_fmdat = TRUE)
+    cmats <- create_confmats(
+      scores = c(0.1, 0.2, 0.2, 0.2, 0.3),
+      labels = c(1, 0, 1, 1, 1),
+      ties_method = ties_method,
+      keep_fmdat = TRUE
+    )
 
     fmdat <- .get_obj(cmats, "fmdat")
 
-    eval(bquote(expect_equal(.get_obj_arg(cmats, NULL, "ties_method"),
-                             ties_method)))
-    eval(bquote(expect_equal(.get_obj_arg(fmdat, NULL, "ties_method"),
-                             ties_method)))
-    eval(bquote(expect_equal(fmdat[["ranks"]], ranks)))
+    expect_equal(.get_obj_arg(cmats, NULL, "ties_method"), ties_method)
+    expect_equal(.get_obj_arg(fmdat, NULL, "ties_method"), ties_method)
+    expect_equal(fmdat[["ranks"]], ranks)
   }
 
   expect_equal_ranks("equiv", c(5, 2, 2, 2, 1))
   expect_equal_ranks("first", c(5, 2, 3, 4, 1))
-
 })
 
 test_that("'cmats' contains a list with 7 items", {
@@ -140,8 +148,10 @@ test_that("'cmats' contains correct items", {
 })
 
 test_that("create_confmats() reterns correct matrices", {
-  cmats <- create_confmats(scores = c(0.1, 0.2, 0, 0.3),
-                           labels = c(1, 0, 0, 1))
+  cmats <- create_confmats(
+    scores = c(0.1, 0.2, 0, 0.3),
+    labels = c(1, 0, 0, 1)
+  )
 
   expect_equal(cmats[["pos_num"]], 2)
   expect_equal(cmats[["neg_num"]], 2)
@@ -152,15 +162,19 @@ test_that("create_confmats() reterns correct matrices", {
 })
 
 test_that("create_confmats() handles tied scores 1", {
-  cmats <- create_confmats(scores = c(0.3, 0.2, 0.2, 0.2, 0.2, 0.1),
-                           labels = c(0, 1, 0, 1, 0, 1))
+  cmats <- create_confmats(
+    scores = c(0.3, 0.2, 0.2, 0.2, 0.2, 0.1),
+    labels = c(0, 1, 0, 1, 0, 1)
+  )
   expect_equal(cmats[["tp"]], c(0, 0, 0.5, 1, 1.5, 2, 3))
   expect_equal(cmats[["fp"]], c(0, 1, 1.5, 2, 2.5, 3, 3))
 })
 
 test_that("create_confmats() handles tied scores 2", {
-  cmats <- create_confmats(scores = c(0.3, 0.2, 0.2, 0.2, 0.2),
-                           labels = c(0, 1, 0, 1, 0))
+  cmats <- create_confmats(
+    scores = c(0.3, 0.2, 0.2, 0.2, 0.2),
+    labels = c(0, 1, 0, 1, 0)
+  )
   expect_equal(cmats[["tp"]], c(0, 0, 0.5, 1, 1.5, 2))
   expect_equal(cmats[["fp"]], c(0, 1, 1.5, 2, 2.5, 3))
 })
@@ -210,8 +224,10 @@ pl3_create_mm_dat <- function() {
 }
 
 test_that("ss test data", {
-  cmats <- create_confmats(scores = c(1, 2, 3, 4),
-                           labels = c(1, 0, 1, 0))
+  cmats <- create_confmats(
+    scores = c(1, 2, 3, 4),
+    labels = c(1, 0, 1, 0)
+  )
 
   expect_equal(cmats[["pos_num"]], 2)
   expect_equal(cmats[["neg_num"]], 2)
@@ -219,14 +235,15 @@ test_that("ss test data", {
   expect_equal(cmats[["fn"]], c(2, 2, 1, 1, 0))
   expect_equal(cmats[["fp"]], c(0, 1, 1, 2, 2))
   expect_equal(cmats[["tn"]], c(2, 1, 1, 0, 0))
-
 })
 
 test_that("ms test data", {
   msdat <- pl3_create_ms_dat()
 
-  cmats1 <- create_confmats(scores = msdat[["scores"]][[1]],
-                            labels = msdat[["labels"]][[1]])
+  cmats1 <- create_confmats(
+    scores = msdat[["scores"]][[1]],
+    labels = msdat[["labels"]][[1]]
+  )
   expect_equal(cmats1[["pos_num"]], 3)
   expect_equal(cmats1[["neg_num"]], 1)
   expect_equal(cmats1[["tp"]], c(0, 1, 2, 2, 3))
@@ -234,8 +251,10 @@ test_that("ms test data", {
   expect_equal(cmats1[["fp"]], c(0, 0, 0, 1, 1))
   expect_equal(cmats1[["tn"]], c(1, 1, 1, 0, 0))
 
-  cmats2 <- create_confmats(scores = msdat[["scores"]][[2]],
-                            labels = msdat[["labels"]][[2]])
+  cmats2 <- create_confmats(
+    scores = msdat[["scores"]][[2]],
+    labels = msdat[["labels"]][[2]]
+  )
   expect_equal(cmats2[["pos_num"]], 3)
   expect_equal(cmats2[["neg_num"]], 1)
   expect_equal(cmats2[["tp"]], c(0, 1, 2, 3, 3))
@@ -243,22 +262,25 @@ test_that("ms test data", {
   expect_equal(cmats2[["fp"]], c(0, 0, 0, 0, 1))
   expect_equal(cmats2[["tn"]], c(1, 1, 1, 1, 0))
 
-  cmats3 <- create_confmats(scores = msdat[["scores"]][[3]],
-                            labels = msdat[["labels"]][[3]])
+  cmats3 <- create_confmats(
+    scores = msdat[["scores"]][[3]],
+    labels = msdat[["labels"]][[3]]
+  )
   expect_equal(cmats3[["pos_num"]], 3)
   expect_equal(cmats3[["neg_num"]], 1)
   expect_equal(cmats3[["tp"]], c(0, 1, 1, 2, 3))
   expect_equal(cmats3[["fn"]], c(3, 2, 2, 1, 0))
   expect_equal(cmats3[["fp"]], c(0, 0, 1, 1, 1))
   expect_equal(cmats3[["tn"]], c(1, 1, 0, 0, 0))
-
 })
 
 test_that("sm test data", {
   smdat <- pl3_create_sm_dat()
 
-  cmats1 <- create_confmats(scores = smdat[["scores"]][[1]],
-                            labels = smdat[["labels"]][[1]])
+  cmats1 <- create_confmats(
+    scores = smdat[["scores"]][[1]],
+    labels = smdat[["labels"]][[1]]
+  )
   expect_equal(cmats1[["pos_num"]], 3)
   expect_equal(cmats1[["neg_num"]], 1)
   expect_equal(cmats1[["tp"]], c(0, 1, 2, 2, 3))
@@ -266,8 +288,10 @@ test_that("sm test data", {
   expect_equal(cmats1[["fp"]], c(0, 0, 0, 1, 1))
   expect_equal(cmats1[["tn"]], c(1, 1, 1, 0, 0))
 
-  cmats2 <- create_confmats(scores = smdat[["scores"]][[2]],
-                            labels = smdat[["labels"]][[2]])
+  cmats2 <- create_confmats(
+    scores = smdat[["scores"]][[2]],
+    labels = smdat[["labels"]][[2]]
+  )
   expect_equal(cmats2[["pos_num"]], 3)
   expect_equal(cmats2[["neg_num"]], 1)
   expect_equal(cmats2[["tp"]], c(0, 1, 2, 3, 3))
@@ -275,22 +299,25 @@ test_that("sm test data", {
   expect_equal(cmats2[["fp"]], c(0, 0, 0, 0, 1))
   expect_equal(cmats2[["tn"]], c(1, 1, 1, 1, 0))
 
-  cmats3 <- create_confmats(scores = smdat[["scores"]][[3]],
-                            labels = smdat[["labels"]][[3]])
+  cmats3 <- create_confmats(
+    scores = smdat[["scores"]][[3]],
+    labels = smdat[["labels"]][[3]]
+  )
   expect_equal(cmats3[["pos_num"]], 3)
   expect_equal(cmats3[["neg_num"]], 1)
   expect_equal(cmats3[["tp"]], c(0, 1, 1, 2, 3))
   expect_equal(cmats3[["fn"]], c(3, 2, 2, 1, 0))
   expect_equal(cmats3[["fp"]], c(0, 0, 1, 1, 1))
   expect_equal(cmats3[["tn"]], c(1, 1, 0, 0, 0))
-
 })
 
 test_that("mm test data", {
   mmdat <- pl3_create_mm_dat()
 
-  cmats1 <- create_confmats(scores = mmdat[["scores"]][[1]],
-                            labels = mmdat[["labels"]][[1]])
+  cmats1 <- create_confmats(
+    scores = mmdat[["scores"]][[1]],
+    labels = mmdat[["labels"]][[1]]
+  )
   expect_equal(cmats1[["pos_num"]], 3)
   expect_equal(cmats1[["neg_num"]], 1)
   expect_equal(cmats1[["tp"]], c(0, 1, 2, 2, 3))
@@ -298,8 +325,10 @@ test_that("mm test data", {
   expect_equal(cmats1[["fp"]], c(0, 0, 0, 1, 1))
   expect_equal(cmats1[["tn"]], c(1, 1, 1, 0, 0))
 
-  cmats2 <- create_confmats(scores = mmdat[["scores"]][[2]],
-                            labels = mmdat[["labels"]][[2]])
+  cmats2 <- create_confmats(
+    scores = mmdat[["scores"]][[2]],
+    labels = mmdat[["labels"]][[2]]
+  )
   expect_equal(cmats2[["pos_num"]], 3)
   expect_equal(cmats2[["neg_num"]], 1)
   expect_equal(cmats2[["tp"]], c(0, 1, 2, 3, 3))
@@ -307,8 +336,10 @@ test_that("mm test data", {
   expect_equal(cmats2[["fp"]], c(0, 0, 0, 0, 1))
   expect_equal(cmats2[["tn"]], c(1, 1, 1, 1, 0))
 
-  cmats3 <- create_confmats(scores = mmdat[["scores"]][[3]],
-                            labels = mmdat[["labels"]][[3]])
+  cmats3 <- create_confmats(
+    scores = mmdat[["scores"]][[3]],
+    labels = mmdat[["labels"]][[3]]
+  )
   expect_equal(cmats3[["pos_num"]], 3)
   expect_equal(cmats3[["neg_num"]], 1)
   expect_equal(cmats3[["tp"]], c(0, 1, 1, 2, 3))
@@ -316,8 +347,10 @@ test_that("mm test data", {
   expect_equal(cmats3[["fp"]], c(0, 0, 1, 1, 1))
   expect_equal(cmats3[["tn"]], c(1, 1, 0, 0, 0))
 
-  cmats4 <- create_confmats(scores = mmdat[["scores"]][[4]],
-                            labels = mmdat[["labels"]][[4]])
+  cmats4 <- create_confmats(
+    scores = mmdat[["scores"]][[4]],
+    labels = mmdat[["labels"]][[4]]
+  )
   expect_equal(cmats4[["pos_num"]], 3)
   expect_equal(cmats4[["neg_num"]], 1)
   expect_equal(cmats4[["tp"]], c(0, 1, 1, 2, 3))
